@@ -14,19 +14,20 @@ import org.apache.tools.ant.BuildException;
 /**
  * Displays module information.
  *
- * @version <pre>$Id: ModuleInfo.java 21628 2008-08-19 22:06:02Z pgier $</pre>
+ * @version <pre>$Id: ModuleInfo.java 24430 2008-12-18 20:06:56Z pgier $</pre>
  * @author  <a href="mailto:jason@planet57.com">Jason Dillon</a>
  */
-public class ModuleInfo
-   extends AbstractInfo
+public class ModuleInfo extends AbstractInfo
 {
    /**
     * Execute this task.
     *
     * @throws BuildException    Failed to execute task.
     */
-   public void execute() throws BuildException {
-      if (!canContinue()) return;
+   public void execute() throws BuildException
+   {
+      if (!canContinue())
+         return;
 
       log.info("Project root: " + getProperty("project.root"));
       log.info(" Module root: " + getProperty("module.root"));
